@@ -2,23 +2,20 @@
 from typing import List, Optional
 
 import numpy as np
-from pydantic import BaseModel
 from sklearn.impute import SimpleImputer
 from sklearn.preprocessing import LabelEncoder
 
 
-class DatasetConfiguration(BaseModel):
+class DatasetConfiguration():
     dependent: str
-    features: Optional[List[str]] = None
-
-
-class PreprocessingConfiguration():
-    testsize: float
     dependent_encoder: bool
+    testsize: float
     imputer: SimpleImputer
+    features: Optional[List[str]] = None
     columns: Optional[List[str]] = None
 
-    def __init__(self, testsize: float, dependent_encode: bool):
+    def __init__(self, dependent: str, testsize: float, dependent_encode: bool):
+        self.dependent = dependent
         self.testsize = testsize
         self.dependent_encoder = LabelEncoder() if dependent_encode else None
         self.imputer = SimpleImputer(missing_values=np.nan, strategy='mean')
